// Int32ArrayMessage.h
/*************************************************************************
* Copyright (c) 2002 The University of Chicago, as Operator of Argonne
* National Laboratory, and the Regents of the University of California, as
* Operator of Los Alamos National Laboratory. MPF is distributed
* subject to a Software License Agreement found in file LICENSE that
* is included with this distribution.
*************************************************************************/

#ifndef Int32ArrayMessageH
#define Int32ArrayMessageH

#include "Message.h"
#include "StandardFieldsMessage.h"
class DLList;

class Int32ArrayMessage : public StandardFieldsMessage
{
public:
    Int32ArrayMessage();
    virtual ~Int32ArrayMessage() {freeValue();}
    virtual int32  toBuffer(char **buffer) const;
    virtual int32  fromBuffer(const char **buffer);
    virtual int32  fromBufferSwitch(const char **buffer);
    virtual void print() const;
    static void *operator new(size_t size);
    void operator delete(void *p, size_t size);
    //Int32ArrayMessage specific methods
    void setLength (int32 length);
    int32 getLength () { return(size/sizeof(int32)); }
    int32 getMaxLength() { return(maxSize/sizeof(int32)); };
    void allocValue(int32 maxLength);
    void freeValue();
    //following are for use by client/server
    int32 *value;
protected:
    Int32ArrayMessage(messageType type);
private:
    static DLList *pFreeList;
    int32 maxSize;          // total alocated bytes
    int32 size;             // total number of bytes in array
    // Disallow copy constructor, assignment operator 
    Int32ArrayMessage(const Int32ArrayMessage&);
    Int32ArrayMessage& operator=(const Int32ArrayMessage&);
};

inline Int32ArrayMessage:: Int32ArrayMessage()
: StandardFieldsMessage(messageTypeInt32Array), maxSize(0), size(0)
{ value=0; }

inline Int32ArrayMessage:: Int32ArrayMessage(messageType type)
: StandardFieldsMessage(type), maxSize(0), size(0)
{ value=0; }

#endif /*Int32ArrayMessageH*/
