// Int32Message.cc
/*************************************************************************
* Copyright (c) 2002 The University of Chicago, as Operator of Argonne
* National Laboratory, and the Regents of the University of California, as
* Operator of Los Alamos National Laboratory. MPF is distributed
* subject to a Software License Agreement found in file LICENSE that
* is included with this distribution.
*************************************************************************/

#include <stdlib.h>
#include <stddef.h>
#include <string.h>
#include <stdio.h>

#include "Message.h"
#include "StandardFieldsMessage.h"
#include "Int32Message.h"

DLList* Int32Message::pFreeList = 0;

int32 Int32Message:: toBuffer(char **buffer) const
{
    int32 nbytes;

    nbytes = StandardFieldsMessage::toBuffer(buffer);
    nbytes += MPF::toBuffer(buffer,value);
    return(nbytes);
}

int32 Int32Message:: fromBuffer(const char **buffer)
{
    int32 nbytes=0;

    nbytes = StandardFieldsMessage::fromBuffer(buffer);
    nbytes += MPF::fromBuffer(buffer,&value);
    return(nbytes);
}

int32 Int32Message:: fromBufferSwitch(const char **buffer)
{
    int32 nbytes=0;

    nbytes = StandardFieldsMessage::fromBufferSwitch(buffer);
    nbytes += MPF::fromBufferSwitch(buffer,&value);
    return(nbytes);
}

void Int32Message:: print() const
{
    StandardFieldsMessage::print();
    printf("value %d\n",value);
}

void *Int32Message:: operator new(size_t size)
{
    if(size==sizeof(Int32Message)) return MPF:: allocate(&pFreeList,size);
    printf("Int32Message new size !=sizeof(Int32Message)\n");
    return(0);
}
 
void Int32Message:: operator delete(void *p, size_t size)
{
    if(size==sizeof(Int32Message)) {
	MPF::free(pFreeList,p,size);
	return;
    }
    printf("Int32Message delete size !=sizeof(Int32Message)\n");
}
