// tcpTest.cc
/*************************************************************************
* Copyright (c) 2002 The University of Chicago, as Operator of Argonne
* National Laboratory, and the Regents of the University of California, as
* Operator of Los Alamos National Laboratory. MPF is distributed
* subject to a Software License Agreement found in file LICENSE that
* is included with this distribution.
*************************************************************************/

#include <stdlib.h>
#include <stddef.h>
#include <string.h>
#include <stdio.h>

#include <semLib.h>
#include <tickLib.h>
#include <taskLib.h>

#include "mpfType.h"
#include "Tcp.h"

typedef struct privateData {
    tcpConnectState connectState;
    long	value;
    bool isServer;
}privateData;

int tcpTestDebug = 0;
int tcpTestNtimes = 10000;

extern "C" {
int tcpTest(bool isServer,int port,const char *address,int bufferSize);
}

Tcp *plasttcpTest = 0;
 
int tcpTestStats()
{
    if(!plasttcpTest) {
        printf("No Tcp task\n");
    } else {
        plasttcpTest->printStats();
    }
    return(0);
}

static const char *isServerString[2] = {"no","yes"};
static void connectCallback(void *pvt,tcpConnectState state)
{
    privateData *pprivateData = (privateData *)pvt;
    
    if(tcpTestDebug)printf("tcpTest connectCallback server %s state %d\n",
	isServerString[(pprivateData->isServer)?1:0],(int)state);
    pprivateData->connectState = state;
}

static void receiveCallback(void *pvt,void *buffer,int32 nbytes)
{
    privateData *pprivateData = (privateData *)pvt;
    
    if(tcpTestDebug)printf("tcpTest receiveCallback server %s ",
	isServerString[(pprivateData->isServer)?1:0]);
    int32 *pvalue = (int32 *)buffer;
    if(tcpTestDebug)printf("value %d nbytes %d\n",*pvalue,nbytes);
}


int tcpTest(int server,int port,const char *address,int bufferSize)
{
    bool isServer = (server? true : false);
    privateData	*pprivateData = new privateData;
    pprivateData->isServer = isServer;
    Tcp *pTcp = new Tcp(isServer,port,address,bufferSize);
    plasttcpTest = pTcp;
    pTcp->connect(pprivateData,connectCallback,receiveCallback);
    int32 value = 0;
    while(true) {
        if(pprivateData->connectState!=tcpConnectYes) {
	    taskDelay(600);
	    continue;
	}
	pTcp->send((void *)&value,sizeof(value));
	value++;
    }
}
